pub struct DebugSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DebugSynchronousProxy
impl DebugSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DebugEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DebugEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn execute(
&self,
args: &[String],
stdout: Socket,
stderr: Socket,
___deadline: MonotonicInstant,
) -> Result<DebugExecuteResult, Error>
pub fn execute( &self, args: &[String], stdout: Socket, stderr: Socket, ___deadline: MonotonicInstant, ) -> Result<DebugExecuteResult, Error>
Executes a command with the provided argument vector.
The argument vector args is passed to the driver’s command handler
as-is, without in-flight modification. The argument vector follows
standard command-line conventions (analogous to argv), where the first
argument (args[0]) is typically the command or subcommand name,
followed by any flags or positional arguments.
Standard output and standard error from command execution are streamed
to the provided stdout and stderr sockets. The driver or command
handler writes to these sockets and closes them upon or before
returning the response.
Returns the command’s process exit code (exit_code), where 0
typically denotes success.
Error
Returns a zx.Status error if the execution request itself fails:
ZX_ERR_INVALID_ARGS:argsis empty.ZX_ERR_NOT_FOUND: The requested command inargs[0]is unknown.
Sourcepub fn list_commands(
&self,
___deadline: MonotonicInstant,
) -> Result<DebugListCommandsResult, Error>
pub fn list_commands( &self, ___deadline: MonotonicInstant, ) -> Result<DebugListCommandsResult, Error>
Lists all supported commands and their descriptions.